            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Currency Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                        <table id="example" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th style="width:150px">Code</th>
                                        <th>Currency Name</th>
                                        <th>Currency Short Name</th>
                                        <th style="width:50px">Status</th>
                                        <th style="width:100px"></th>
                                    </tr>
                                </thead>                                     
                                <tbody id="tbl_content">
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>


<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Currency Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
             <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                <div class="row">
                    <span id="ErrCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Currency Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencyName" id="CurrencyName" placeholder="Currency Name" onkeypress="clearInput('CurrencyName')">
                        <span id="ErrCurrencyName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Currency Short Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencyShortName" id="CurrencyShortName" placeholder="Currency Short  Name" onkeypress="clearInput('CurrencyShortName')">
                        <span id="ErrCurrencyShortName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Currency Symbol</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencySymbolName" id="CurrencySymbol" placeholder="Currency Symbol" onkeypress="clearInput('CurrencySymbol')">
                        <span id="ErrCurrencySymbol" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
             </form>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Currency Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>        
            <div class="modal-body">
             <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
             <input type="hidden" name="ID" id="editID">
                <div class="row">
                <span id="ErreditCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label>
                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Currency Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencyName" id="editCurrencyName" placeholder="Currency Name" value="" onkeypress="clearInput('editCurrencyName')">
                        <span id="ErreditCurrencyName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Currency Short Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencyShortName" id="editCurrencyShortName" placeholder="Currency Short Name" value="" onkeypress="clearInput('editCurrencyShortName')">
                        <span id="ErreditCurrencyShortName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Currency Symbol</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CurrencySymbol" id="editCurrencySymbol" placeholder="Currency Symbol" value="" onkeypress="clearInput('editCurrencySymbol')">
                        <span id="ErreditCurrencySymbol" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1">Active</option>
                            <option value="0">Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
             </form>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Currency Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Code</div>
                        <div id="viewCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Currency Name</div>
                        <div id="viewCurrencyName"></div>
                    </div> 
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Currency Short Name</div>
                        <div id="viewCurrencyShortName"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Currency Symbol</div>
                        <div id="viewCurrencySymbol"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <div id="viewRemarks"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <div id="viewStatus"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <div id="viewCreatedOn"></div>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>

 function list() {
      $('#Success').modal("hide");
    $.post(URL+ "webservice.php?action=l&method=mccorl","",function(data){
      var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            $.each(obj.data, function (index, data) {
                 html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                            + '<td>' + data.Code + '</td>'
                            + '<td>' + data.CurrencyName + '</td>' 
                            + '<td>' + data.CurrencySymbol + '</td>' 
                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
                             + '<td style="text-align:right">' 
                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                               + '</td>'
                             + '</tr>';
                      + '</tr>';
            });
            if(obj.data.length==0){
            html += '<tr>'
                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
                + '</tr>'
            }   
            $('#tbl_content').html(html);
        } else {
             $('#popupcontent').html( error(obj.message));
        }  
    });
}

setTimeout("list()",2000);  

function addform(){
        $('#confirmationtoadd').modal("show"); 
        $('#Code').val(""); 
        $('#CurrencyName').val(""); 
        $('#CurrencyShortName').val(""); 
        $('#CurrencySymbol').val(""); 
        $('#Remarks').val(""); 
        
        $('#ErrCode').html("");
        $('#ErrCurrencyName').html(""); 
        $('#ErrCurrencyShortName').html(""); 
        $('#ErrCurrencySymbol').html(""); 
        $('#ErrRemarks').html("");
        $('#ErrCommon').html("");
    
        $("#Code").removeClass("highlight_error"); 
        $("#CurrencyName").removeClass("highlight_error"); 
        $("#CurrencyShortName").removeClass("highlight_error"); 
        $("#CurrencySymbol").removeClass("highlight_error"); 
        $("#Remarks").removeClass("highlight_error"); 
}

function add(){
     var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
          $("#Code").addClass("highlight_error"); 
           error++;
    }  else {
         $("#Code").removeClass("highlight_error"); 
            $('#ErrCode').html(""); 
    }
    if ($('#CurrencyName').val()==""){
            $('#ErrCurrencyName').html("Please enter Currency Name");
          $("#CurrencyName").addClass("highlight_error"); 
           error++;
    }  else {
          $("#CurrencyName").removeClass("highlight_error"); 
            $('#ErrCurrencyName').html(""); 
    }  
    if ($('#CurrencyShortName').val()==""){
            $('#ErrCurrencyShortName').html("Please enter Currency Short Name");
          $("#CurrencyShortName").addClass("highlight_error"); 
           error++;
    }  else {
          $("#CurrencyShortName").removeClass("highlight_error"); 
            $('#ErrCurrencyShortName').html(""); 
    } 
    if ($('#CurrencySymbol').val()==""){
            $('#ErrCurrencySymbol').html("Please enter Currency Symbol");
          $("#CurrencySymbol").addClass("highlight_error"); 
           error++;
    }  else {
          $("#CurrencySymbol").removeClass("highlight_error"); 
            $('#ErrCurrencySymbol').html(""); 
    } 
  
     if(error==0){
        var param = $('#frm_create').serialize();
        $.post(URL+"webservice.php?action=a&method=mccorl",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoadd').modal("hide"); 
             $('#Success').modal("show");    
        }   else {
            $('#ErrCommon').html(print_inlineError(obj.message));
        }
    });
   }
}

function editform(ID){
     $('#confirmationtoedit').modal("show");
     $('#ErreditCode').html("");
     $('#ErreditCurrencyName').html(""); 
     $('#ErreditCurrencySymbol').html(""); 
     $('#ErreditRemarks').html(""); 
     $("#editCode").removeClass("highlight_error"); 
     $("#editCurrencyName").removeClass("highlight_error"); 
     $("#editCurrencyShortName").removeClass("highlight_error"); 
     $("#editCurrencySymbol").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error");
      $.post(URL+ "webservice.php?action=g&method=mccorl&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            $.each(obj.data, function (index, data) {
                $('#editCode').val(data.Code);
                $('#editID').val(data.ID);
                $('#editCurrencyName').val(data.CurrencyName);
                $('#editCurrencyShortName').val(data.CurrencyShortName);
                $('#editStatus').val(data.Status);
                $('#editRemarks').val(data.Remarks);
            });   
}  
        else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
  });
}

function edit(ID){
    var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
          $("#editCode").addClass("highlight_error"); 
           error++;
    }  else {
         $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
     if ($('#editCurrencyName').val()==""){
            $('#ErreditCurrencyName').html("Please enter Currency Name");
         $("#editCurrencyName").addClass("highlight_error");
            error++;
    }  else {
        $("#editCurrencyName").removeClass("highlight_error"); 
            $('#ErreditCurrencyName').html(""); 
    } 
     if ($('#editCurrencyShortName').val()==""){
            $('#ErreditCurrencyShortName').html("Please enter Currency Short Name");
         $("#editCurrencyShortName").addClass("highlight_error"); 
            error++;
    }  else {
        $("#editCurrencyShortName").removeClass("highlight_error"); 
            $('#ErreditCurrencyShortName').html(""); 
    } 
     if ($('#editCurrencySymbol').val()==""){
            $('#ErreditCurrencySymbol').html("Please enter Currency Symbol");
         $("#editCurrencySymbol").addClass("highlight_error"); 
            error++;
    }  else {
        $("#editCurrencySymbol").removeClass("highlight_error"); 
            $('#ErreditCurrencySymbol').html(""); 
    } 
      if(error==0){
        var param = $('#frm_edit').serialize();
        $.post(URL+"webservice.php?action=u&method=mccorl",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoedit').modal("hide");
             $('#Success').modal("show");  
        }   else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
    });
   }
  
}

function viewform(ID){
     $('#confirmationtoview').modal("show"); 
       $.post(URL+ "webservice.php?action=g&method=mccorl&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            $.each(obj.data, function (index, data) {
                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                $('#viewCurrencyName').html(data.CurrencyName=="" ? "&nbsp;" : data.CurrencyName);
                $('#viewCurrencyShortName').html(data.CurrencyShortName=="" ? "&nbsp;" : data.CurrencyShortName);
                $('#viewCurrencySymbol').html(data.CurrencySymbol=="" ? "&nbsp;" : data.CurrencySymbol);
                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                $('#viewCreatedOn').html(data.CreatedOn);
               if(data.Status=="1"){
                $('#viewStatus').html("Active");    
               }
               if(data.Status=="0"){
                $('#viewStatus').html("Deactive");    
               }
            });   
}  
  }) 
}

//Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphanumeric Space Dot only correct */ 
var arr = ["CurrencyName","editCurrencyName","CurrencyShortName","editCurrencyShortName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphanumeric Space Dot only correct */ 
var arr = ["CurrencySymbol","editCurrencySymbol",];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}              
</script>
    